@@ -11,6 +11,8 @@ import datetime as dt
 from django.conf import settings
 from django.core.exceptions import MiddlewareNotUsed
 from django.core.mail.message import EmailMessage
+from django.core.urlresolvers import resolve
+
 from dogslow.timer import Timer
 
 class SafePrettyPrinter(pprint.PrettyPrinter, object):
@@ -90,7 +92,7 @@ class WatchdogMiddleware(object):
     def peek(request, thread_id, started):
         try:
             frame = sys._current_frames()[thread_id]
-
+            
             req_string = '%s %s://%s%s' % (
                 request.META.get('REQUEST_METHOD'),
                 request.META.get('wsgi.url_scheme', 'http'),
@@ -137,17 +139,33 @@ class WatchdogMiddleware(object):
                                   (getattr(settings, 'DOGSLOW_EMAIL_TO'),))
                 em.send(fail_silently=True)
 
+            # and a custom logger:
+            if hasattr(settings, 'DOGSLOW_LOGGER'):
+                logger = logging.getLogger(getattr(settings, 'DOGSLOW_LOGGER'))
+                logger.warn('Slow Request Watchdog: %s, %%s - %%s' %
+                            resolve(request.META.get('PATH_INFO')).url_name,
+                            str(req_string), output)
+
         except Exception:
             logging.exception('Request watchdog failed')
 
 
+    def _is_exempt(self, request):
+        """Returns True if this request's URL resolves to a url pattern whose
+        name is listed in settings.DOGSLOW_IGNORE_URLS.
+        """
+        match = resolve(request.META.get('PATH_INFO'))
+        return match and (match.url_name in
+                       getattr(settings, 'DOGSLOW_IGNORE_URLS', ()))
+
     def process_request(self, request):
-        request.dogslow = self.timer.run_later(
-            WatchdogMiddleware.peek,
-            self.interval,
-            request,
-            thread.get_ident(),
-            dt.datetime.utcnow())
+        if not self._is_exempt(request):
+            request.dogslow = self.timer.run_later(
+                WatchdogMiddleware.peek,
+                self.interval,
+                request,
+                thread.get_ident(),
+                dt.datetime.utcnow())
 
     def _cancel(self, request):
         try:
